@@ -3,7 +3,7 @@ use std::fs::create_dir_all;
 
 use cosmwasm_schema::{export_schema, remove_schemas, schema_for};
 
-use cw20_permission_based_token::msg::{ExecuteMsg, QueryMsg, InstantiateMsg};
+use cw20_factory_token::msg::{ExecuteMsg, QueryMsg, InstantiateMsg};
 
 fn main() {
     let mut out_dir = current_dir().unwrap();
