@@ -11,10 +11,10 @@ use crate::state::{Config, CONFIG};
 use cw2::set_contract_version;
 use cw20_base::allowances::{
     execute_decrease_allowance, execute_increase_allowance, execute_send_from,
-    execute_transfer_from, query_allowance,
+    execute_transfer_from, query_allowance, execute_burn_from,
 };
 use cw20_base::contract::{
-    execute_burn, execute_mint, execute_send, execute_transfer, execute_update_marketing,
+    execute_mint, execute_send, execute_transfer, execute_update_marketing,
     execute_upload_logo, query_balance, query_token_info, query_minter, query_download_logo, query_marketing_info,
 };
 
@@ -55,8 +55,8 @@ pub fn execute(
     match msg {
         /* Extended methods with the limitation that the only one allowed
         to successfully complete its execution is the address form config.token_factory_addr */
-        ExecuteMsg::Burn { amount } => Ok(try_burn(deps, env, info, amount)?),
         ExecuteMsg::Mint { recipient, amount } => Ok(try_mint(deps, env, info, recipient, amount)?),
+        ExecuteMsg::BurnFrom { owner, amount } => Ok(try_burn_from(deps, env, info, owner, amount)?),
         
         /* Default methods from CW20 Standard with no modifications:
         https://github.com/CosmWasm/cw-plus/tree/main/contracts/cw20-base */
@@ -113,10 +113,11 @@ pub fn execute(
     }
 }
 
-pub fn try_burn(
+pub fn try_burn_from(
     deps: DepsMut,
     env: Env,
     info: MessageInfo,
+    owner: String,
     amount: Uint128,
 ) -> Result<Response, ContractError> {
     let config = CONFIG.load(deps.storage)?;
@@ -128,7 +129,8 @@ pub fn try_burn(
             expected: config.token_factory_addr,
         });
     }
-    Ok(execute_burn(deps, env, info, amount)?)
+    
+    Ok(execute_burn_from(deps, env, info, owner, amount )?)
 }
 
 pub fn try_mint(
